@@ -11,7 +11,7 @@ set -o pipefail
 
 display_help() {
   cat << EOF
-usage: debcraft <build|improve|test|release|shell|prune> [options] [<path|pkg|srcpkg|dsc|git-url>]
+usage: debcraft <build|improve|test|release|update|shell|logs|prune> [options] [<path|pkg|srcpkg|dsc|git-url>]
 
 Debcraft is a tool to easily build .deb packages. The 'build' argument accepts
 as a subargument any of:
@@ -25,11 +25,16 @@ as a subargument any of:
 
   * git http(s) or ssh URL that can be downloaded and built
 
-The command 'release' is intended to be used to upload a package that is ready
-to be released. The command 'test' will run the Debian-specific regression test
-suite if the package has autopkgtest support, and drop to a shell for
-investigation if tests failed to pass. The command 'shell' can be used to play
-around in the container and 'prune' will clean up temporary files by Debcraft.
+The command 'improve' will try to apply various improvements to the package
+based on tools in Debian that automate package maintenance. The command 'test'
+will run the Debian-specific regression test suite if the package has
+autopkgtest support, and drop to a shell for investigation if tests failed to
+pass. The command 'release' is intended to be used to upload a package that is
+ready to be released and command 'update' will try to update the package to
+laters upstream version is package git repository layout is compatible.
+
+The command 'shell' can be used to play around in the container and 'prune' will
+clean up temporary files by Debcraft.
 
 In addition to parameters below, anything passed in DEB_BUILD_OPTIONS will also
 be honored (currently DEB_BUILD_OPTIONS='$DEB_BUILD_OPTIONS'). Successful builds
@@ -40,7 +45,7 @@ Note that Debcraft builds never runs as root, and thus packages with
 DEB_RULES_REQUIRES_ROOT are not supported.
 
 optional arguments:
-  --build-dirs-path    Path for writing build files and artifacts (default: parent directory)
+  --build-dirs-path    Path for writing build files and artifacts (default: ~/.cache/debcraft)
   --distribution       Linux distribution to build in (default: debian:sid)
   --container-command  container command to use (default: podman)
   --host-architecture  host architecture to use when performing a cross build
@@ -123,7 +128,7 @@ source "$DEBCRAFT_LIB_DIR/generic.inc.sh"
 
 if [ -z "$1" ]
 then
-  log_error "Missing argument <build|improve|test|release|shell|prune>"
+  log_error "Missing argument <build|improve|test|release|shell|logs|prune>"
   echo
   display_help
   exit 1
@@ -134,8 +139,14 @@ log_debug "Parse option/argument: $1"
 do
   case "$1" in
     --build-dirs-path)
-      export BUILD_DIRS_PATH="$2"
-      log_debug "Using BUILD_DIRS_PATH=$2"
+      if [ -z "$2" ] || [ ! -d "$2" ]
+      then
+        log_error "Parameter --build-dirs-path requires a path"
+        exit 1
+      fi
+      BUILD_DIRS_PATH="$(readlink -f "$2")"
+      export BUILD_DIRS_PATH
+      log_debug "Using BUILD_DIRS_PATH=$BUILD_DIRS_PATH"
       shift 2
       ;;
     --distribution)
@@ -195,7 +206,7 @@ do
       ## or call function display_help
       exit 1
       ;;
-    build | improve | test | release | shell | prune)
+    build | improve | test | release | update | shell | logs | prune)
       export ACTION="$1"
       shift
       ;;
@@ -210,7 +221,7 @@ done
 if [ -z "$ACTION" ]
 then
   # If ACTION is empty the TARGET might have been populated
-  log_error "Argument '$TARGET' not one of <build|improve|test|release|shell|prune>"
+  log_error "Argument '$TARGET' not one of <build|improve|test|release|update|shell|logs|prune>"
   echo
   display_help
   exit 1
@@ -232,6 +243,14 @@ then
   exit 1
 fi
 
+if [ -n "$DISTRIBUTION" ] && { [ "$ACTION" == "logs" ] || [ "$ACTION" == "update" ]; }
+then
+  log_error "Parameter --distribution is not supported for action '$ACTION'"
+  echo
+  display_help
+  exit 1
+fi
+
 log_debug_var ACTION
 
 # Configure general program behaviour after user options and arguments have been parsed
@@ -268,7 +287,7 @@ elif [ -d "$TARGET" ]
 then
   # If an argument was given, and it is a directory, use TARGET as-is
   :
-elif [ ! -d "$TARGET" ] && [[ "build improve" =~ $ACTION ]]
+elif [ ! -d "$TARGET" ] && [[ "build improve update" =~ $ACTION ]]
 then
   # If the argument exists, but didn't point to a valid path, try to use the
   # argument to download the package
@@ -361,7 +380,7 @@ reset_if_source_repository_and_option_clean
 source "$DEBCRAFT_LIB_DIR/config-package.inc.sh"
 
 # If the action needs to run in a container, automatically create it
-if [ "$ACTION" != "prune" ]
+if [ "$ACTION" != "update" ] && [ "$ACTION" != "prune" ] && [ "$ACTION" != "logs" ]
 then
   # shellcheck source=src/container.inc.sh
   source "$DEBCRAFT_LIB_DIR/container.inc.sh"
@@ -388,10 +407,18 @@ case "$ACTION" in
     # shellcheck source=src/release-dput.inc.sh
     source "$DEBCRAFT_LIB_DIR/release-dput.inc.sh"
     ;;
+  update)
+    # shellcheck source=src/update.inc.sh
+    source "$DEBCRAFT_LIB_DIR/update.inc.sh"
+    ;;
   shell)
     # shellcheck source=src/shell.inc.sh
     source "$DEBCRAFT_LIB_DIR/shell.inc.sh"
     ;;
+  logs)
+    # shellcheck source=src/logs.inc.sh
+    source "$DEBCRAFT_LIB_DIR/logs.inc.sh"
+    ;;
   prune)
     # shellcheck source=src/prune.inc.sh
     source "$DEBCRAFT_LIB_DIR/prune.inc.sh"
