@@ -12,6 +12,9 @@ set -o pipefail
 # shellcheck source=src/container/output.inc.sh
 source "/output.inc.sh"
 
+# shellcheck source=src/container/cache.inc.sh
+source "/cache.inc.sh"
+
 # shellcheck source=src/container/debcraft-repository.sh
 source "/debcraft-repository.sh"
 
@@ -25,7 +28,9 @@ if [ -f debian/patches/series ]
 then
   log_info "Apply patches with Quilt"
   export QUILT_PATCHES=debian/patches
-  quilt push -a
+    # If all patches have already been applied, attempting to push any more results
+    # in an exit status of 2.  As this is not an error, it should be ignored.
+    quilt push -a || [ $? -eq 2 ]
 fi
 
 
