@@ -8,10 +8,12 @@
 # shellcheck disable=SC2086
 $CONTAINER_CMD run \
     --name="$DOWNLOAD_CONTAINER" \
-    --interactive --tty --rm \
-    --volume="$PWD":/tmp/debcraft \
-    --workdir=/tmp/debcraft \
-    $CONTAINER_RUN_ARGS \
+    --interactive \
+    ${CONTAINER_CAN_HAVE_TTY:+--tty} \
+    --rm \
+    --volume="$PWD":/debcraft \
+    --workdir=/debcraft \
+    "${CONTAINER_RUN_ARGS[@]}" \
     "$DOWNLOAD_CONTAINER" \
     /debcraft-downloader.sh "$TARGET" \
     || FAILURE="true"
